Crate ohos_crypto_sys

Crate ohos_crypto_sys 

Bindings to the OpenHarmony CryptoArchitectureKit (libohcrypto.so).

Overview

CryptoArchitectureKit is the OpenHarmony cryptographic framework. It provides APIs for message digests, MAC, symmetric and asymmetric key generation, symmetric and asymmetric ciphers, signatures, key agreement, KDFs and random number generation.

Available since OpenHarmony API-level 12. The asymmetric cipher, KDF, key agreement, MAC and random number generator modules were added in API-level 20.

See also the official CryptoArchitectureKit documentation.

Feature flags

  • api-12 — Enables bindings for OpenHarmony API-level 12. The CryptoArchitectureKit is first available at this API level, so this is the minimum supported feature.

  • api-13 — Enables bindings for OpenHarmony API-level 13 (No changes).

  • api-14 — Enables bindings for OpenHarmony API-level 14 (No changes).

  • api-15 — Enables bindings for OpenHarmony API-level 15 (No changes).

  • api-16 — Enables bindings for OpenHarmony API-level 16 (No changes).

  • api-17 — Enables bindings for OpenHarmony API-level 17 (No changes).

  • api-18 — Enables bindings for OpenHarmony API-level 18 (No changes).

  • api-19 — Enables bindings for OpenHarmony API-level 19 (No changes).

  • api-20 — Enables bindings for OpenHarmony API-level 20.

    Adds asymmetric cipher, KDF, key agreement, MAC and random number generator modules, plus various items added to existing modules.

  • api-21 — Enables bindings for OpenHarmony API-level 21 (No changes).

  • document-features — Document available features when building the documentation

Modules

asym_cipherapi-20
asym_keyapi-12
commonapi-12
digestapi-12
kdfapi-20
key_agreementapi-20
macapi-20
randapi-20
signatureapi-12
sym_cipherapi-12
sym_keyapi-12