#[repr(transparent)]pub struct CryptoMac_ParamType(pub c_uint);Available on crate feature
api-20 only.Expand description
Defines the MAC algorithm parameter type.
Available since API-level: 20
Tuple Fields
0: c_uintImplementations
Sourceimpl CryptoMac_ParamType
impl CryptoMac_ParamType
Sourcepub const CRYPTO_MAC_DIGEST_NAME_STR: CryptoMac_ParamType
pub const CRYPTO_MAC_DIGEST_NAME_STR: CryptoMac_ParamType
Indicates the algorithm name of the message digest function for HMAC. e.g. “SHA256”.
Sourcepub const CRYPTO_MAC_CIPHER_NAME_STR: CryptoMac_ParamType
pub const CRYPTO_MAC_CIPHER_NAME_STR: CryptoMac_ParamType
Indicates the algorithm name of the symmetric cipher function for CMAC. e.g. “AES256”.